| Title: | DNA Cyclizability Prediction |
|---|---|
| Description: | This package performs prediction of intrinsic cyclizability of of every 50-bp subsequence in a DNA sequence. The input could be a file either in FASTA or text format. The output will be the C-score, the estimated intrinsic cyclizability score for each 50 bp sequences in each entry of the sequence set. |
| Authors: | Brody Kendall [aut], Keren Li [aut], Ji-Ping Wang [aut, cre] (ORCID: <https://orcid.org/0000-0002-8398-939X>) |
| Maintainer: | Ji-Ping Wang <[email protected]> |
| License: | Artistic-2.0 |
| Version: | 1.5.1 |
| Built: | 2026-06-02 06:41:28 UTC |
| Source: | https://github.com/bioc/DNAcycP2 |
This predicts cyclizability for a set of sequences.
cycle(sequences, smooth, save_path_prefix = "")cycle(sequences, smooth, save_path_prefix = "")
sequences |
A list or vector of sequences |
smooth |
Whether to predict smoothed C0 (DNAcycP2) or original C0 (DNAcycP) |
save_path_prefix |
Base path for output files. If it is an empty string, the output files will not be saved (default="") |
Optionally, saves output files (use argument 'save_path_prefix')
A list of predictions for each input sequence.
# Example usage of cycle cycle(c("ACTGCTAGTCACTGCTAGTCACTGCTAGTCACTGCTAGTCACTGCTAGTC"), smooth=TRUE) # where sequences is a list/vector of sequences# Example usage of cycle cycle(c("ACTGCTAGTCACTGCTAGTCACTGCTAGTCACTGCTAGTCACTGCTAGTC"), smooth=TRUE) # where sequences is a list/vector of sequences
This predicts cyclizability for all subsequences of length 50bp from a .fasta input file.
cycle_fasta( file_path, smooth, n_cores = 1, chunk_length = 1e+05, save_path_prefix = "" )cycle_fasta( file_path, smooth, n_cores = 1, chunk_length = 1e+05, save_path_prefix = "" )
file_path |
.fasta input file path |
smooth |
Whether to predict smoothed C0 (DNAcycP2) or original C0 (DNAcycP) |
n_cores |
Number of cores to use for parallel processing (default=1) |
chunk_length |
Length of sequence that each core will predict on at a given time. (default=100000) |
save_path_prefix |
Base path for output files. If it is an empty string, the output files will not be saved (default="") |
Optionally, saves output files (use argument 'save_path_prefix')
A list of predictions for each ID in the .fasta file.
Each list item has the following columns: position, c_score_norm ( predictions on a normalized scale), and c_score_unnorm (predictions on an unnormalized scale).
Each list item is named "cycle_$id$" corresponding to the fasta id
# Create a temporary file temp_file <- tempfile(fileext = ".fasta") writeLines( c(">1", "ACTGCTAGTCACTGCTAGTCACTGCTAGTCACTGCTAGTCACTGCTAGTC"), temp_file ) # Example usage of cycle_fasta cycle_fasta(temp_file, smooth=TRUE) # Cleanup unlink(temp_file)# Create a temporary file temp_file <- tempfile(fileext = ".fasta") writeLines( c(">1", "ACTGCTAGTCACTGCTAGTCACTGCTAGTCACTGCTAGTCACTGCTAGTC"), temp_file ) # Example usage of cycle_fasta cycle_fasta(temp_file, smooth=TRUE) # Cleanup unlink(temp_file)